import * as pretty_format from 'pretty-format';
import { S as SuiteCollector, T as TestFunction, a as TestFactory, b as Suite, U as UserOptions } from './types-d3253f2d';
export { C as ConcurrentOptions, F as File, G as GlobalContext, H as HookListener, h as Reporter, R as ResolvedConfig, c as RunMode, g as RunnerContext, b as Suite, S as SuiteCollector, e as Task, d as TaskState, f as TestCollector, a as TestFactory, T as TestFunction, U as UserOptions } from './types-d3253f2d';
export { assert, default as chai, expect, should } from 'chai';
import sinon from 'sinon';
export { default as sinon } from 'sinon';
import '@antfu/utils';
import 'jest-snapshot';
import 'jest-snapshot/build/State';

declare const defaultSuite: SuiteCollector;
declare const test: {
    (name: string, fn: TestFunction): void;
    concurrent: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        skip(name: string, fn: TestFunction, timeout?: number | undefined): void;
        only(name: string, fn: TestFunction, timeout?: number | undefined): void;
        todo(name: string): void;
    };
    skip: {
        (name: string, fn: TestFunction): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    only: {
        (name: string, fn: TestFunction): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    todo: {
        (name: string): void;
        concurrent(name: string): void;
    };
};
declare function suite(suiteName: string, factory?: TestFactory): SuiteCollector;
declare namespace suite {
    var skip: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    var only: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    var todo: (suiteName: string) => SuiteCollector;
}
declare const describe: typeof suite;
declare const it: {
    (name: string, fn: TestFunction): void;
    concurrent: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        skip(name: string, fn: TestFunction, timeout?: number | undefined): void;
        only(name: string, fn: TestFunction, timeout?: number | undefined): void;
        todo(name: string): void;
    };
    skip: {
        (name: string, fn: TestFunction): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    only: {
        (name: string, fn: TestFunction): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    todo: {
        (name: string): void;
        concurrent(name: string): void;
    };
};
declare const beforeAll: (fn: Suite['hooks']['beforeAll'][0]) => void;
declare const afterAll: (fn: Suite['hooks']['afterAll'][0]) => void;
declare const beforeEach: (fn: Suite['hooks']['beforeEach'][0]) => void;
declare const afterEach: (fn: Suite['hooks']['afterEach'][0]) => void;
declare function clearContext(): void;

declare const mock: sinon.SinonMockStatic;
declare const spy: sinon.SinonSpyStatic;
declare const stub: sinon.SinonStubStatic;

declare module 'vite' {
    interface UserConfig {
        /**
         * Options for Vitest
         */
        test?: UserOptions;
    }
}
declare global {
    namespace Chai {
        interface Assertion {
            toMatchSnapshot(message?: string): Assertion;
            matchSnapshot(message?: string): Assertion;
            toEqual(expected: any): void;
            toStrictEqual(expected: any): void;
            toBe(expected: any): void;
            toMatch(expected: string | RegExp): void;
            toMatchObject(expected: any): void;
            toContain(item: any): void;
            toBeTruthy(): void;
            toBeFalsy(): void;
            toBeNaN(): void;
            toBeUndefined(): void;
            toBeNull(): void;
            toBeDefined(): void;
            toBeInstanceOf(c: any): void;
            toHaveBeenCalledTimes(n: number): void;
            toHaveBeenCalledOnce(): void;
            toHaveBeenCalled(): void;
            toHaveBeenCalledWith(...args: any[]): void;
        }
        interface ExpectStatic {
            addSnapshotSerializer: pretty_format.Plugin;
        }
    }
}

export { afterAll, afterEach, beforeAll, beforeEach, clearContext, defaultSuite, describe, it, mock, spy, stub, suite, test };
